import MessageType from './MessageType';
import SerializationFormat, { ISerializerFunctions } from './SerializationFormat';
/**
 * Mark an attribute as a 32-bit float
 *
 * @param target
 * @param propertyKey
 */
export declare function Float32<T extends MessageType>(target: T, propertyKey: string): void;
/**
 * Mark an attribute as a 64-bit float
 *
 * @param target
 * @param propertyKey
 */
export declare function Float64<T extends MessageType>(target: T, propertyKey: string): void;
/**
 * Mark an attribute as a 8-bit signed integer
 *
 * @param target
 * @param propertyKey
 */
export declare function Int8<T extends MessageType>(target: T, propertyKey: string): void;
/**
 * Mark an attribute as a 16-bit signed integer
 *
 * @param target
 * @param propertyKey
 */
export declare function Int16<T extends MessageType>(target: T, propertyKey: string): void;
/**
 * Mark an attribute as a 32-bit signed integer
 *
 * @param target
 * @param propertyKey
 */
export declare function Int32<T extends MessageType>(target: T, propertyKey: string): void;
/**
 * Mark an attribute as a 8-bit unsigned integer
 *
 * @param target
 * @param propertyKey
 */
export declare function Uint8<T extends MessageType>(target: T, propertyKey: string): void;
/**
 * Mark an attribute as a 16-bit unsigned integer
 *
 * @param target
 * @param propertyKey
 */
export declare function Uint16<T extends MessageType>(target: T, propertyKey: string): void;
/**
 * Mark an attribute as a 32-bit unsigned integer
 *
 * @param target
 * @param propertyKey
 */
export declare function Uint32<T extends MessageType>(target: T, propertyKey: string): void;
/**
 * Binary Serialization Format
 *
 * This serialization format will serialize and deserialize messages based
 * on the attribute information registered by the different decorators provided
 * by this module.
 *
 * ```typescript
 * import { Type, TypeIds } from '../'
 * import MessageType from 'megadata/classes/MessageType'
 * import Binary, { Uint32 } from 'megadata/classes/BinarySerializationFormat'
 *
 * @Type(TypeIds.Join, Binary)
 * export default class Join extends MessageType {
 *   @Uint32
 *   public time?: number
 * }
 * ```
 */
export default class BinarySerializationFormat extends SerializationFormat {
    /**
     * Create serialization and deserialization hooks to be applied onto the message class
     *
     * @param id
     * @param size
     * @param attributes
     */
    static create<I extends number, T extends MessageType>(id: I, size: number, attributes: any): ISerializerFunctions<T>;
}
