import MessageType from './MessageType';
import SerializationFormat, { ISerializerFunctions } from './SerializationFormat';
/**
 * JSON Serialization Format
 *
 * This serialization format will stringify objects to JSON and
 * returned them as an ArrayBuffer prefixed with the message ID.
 * No additional attribute decorators are required
 *
 * ```typescript
 * import { Type, TypeIds } from '../'
 * import MessageType from 'megadata/classes/MessageType'
 * import Json from 'megadata/classes/JsonSerializationFormat'
 *
 * @Type(TypeIds.Leave, Json)
 * export default class Leave extends MessageType {
 *   public time?: number
 * }
 * ```
 */
export default class JsonSerializationFormat extends SerializationFormat {
    /**
     * Maximum buffer size
     *
     * This represents the maximum size of pooled buffers.
     */
    static maxByteSize: number;
    /**
     * Create serialization and deserialization hooks to be applied onto the message class
     *
     * @param id
     * @param _size
     * @param _attributes
     */
    static create<I extends number, T extends MessageType>(id: I, _size: number, _attributes: any): ISerializerFunctions<T>;
}
